# Changelog

## [0.1.8](https://github.com/matchdav/clew-engine/compare/clewso-core-v0.1.7...clewso-core-v0.1.8) (2026-03-26)


### Features

* **ladybug:** integration of embedded db ([e84898d](https://github.com/matchdav/clew-engine/commit/e84898da24c133254eaaace448370e9c7c9677cc))

## [0.1.7](https://github.com/matchdav/clew-engine/compare/clewso-core-v0.1.6...clewso-core-v0.1.7) (2026-03-20)


### Miscellaneous Chores

* **clewso-core:** Synchronize clewso versions

## [0.1.6](https://github.com/matchdav/clew-engine/compare/clewso-core-v0.1.5...clewso-core-v0.1.6) (2026-03-19)


### Miscellaneous Chores

* **clewso-core:** Synchronize clewso versions

## [0.1.5](https://github.com/matchdav/clew-engine/compare/clewso-core-v0.1.4...clewso-core-v0.1.5) (2026-03-19)


### Miscellaneous Chores

* **clewso-core:** Synchronize clewso versions

## [0.1.4](https://github.com/matchdav/clew-engine/compare/clewso-core-v0.1.3...clewso-core-v0.1.4) (2026-03-19)


### Features

* add --version/-V flag, fix publish workflow and project URLs ([229a780](https://github.com/matchdav/clew-engine/commit/229a780f15a253ca629aa70bbf533e0226b44c10))

## [0.1.3](https://github.com/matchdav/clew-engine/compare/clewso-core-v0.1.2...clewso-core-v0.1.3) (2026-03-19)


### Miscellaneous Chores

* **clewso-core:** Synchronize clewso versions

## [0.1.2](https://github.com/matchdav/clew-engine/compare/clewso-core-v0.1.1...clewso-core-v0.1.2) (2026-03-19)


### Miscellaneous Chores

* **clewso-core:** Synchronize clewso versions

## [0.1.1](https://github.com/matchdav/clew-engine/compare/clewso-core-v0.1.0...clewso-core-v0.1.1) (2026-03-19)


### Features

* **clew-core:** Add DCP Pydantic V2 schemas — DomainNode, ConceptNode, PreceptNode ([#81](https://github.com/matchdav/clew-engine/issues/81)) ([e2fb14c](https://github.com/matchdav/clew-engine/commit/e2fb14ca8a14bcf1df867193cd2b5025b8c60486))
* setup pre-commit ([#70](https://github.com/matchdav/clew-engine/issues/70)) ([950deec](https://github.com/matchdav/clew-engine/commit/950deec4be3f04adad257ebb7c8044d1d3106845))
* **types:** Phase 3.1 — TypedDicts for core data models, Pyright configs ([1dc768d](https://github.com/matchdav/clew-engine/commit/1dc768d59cffa0c65bf4f99faa11db38f40160f5))
